@@ -51,6 +51,9 @@ customizable_key_values = {
 	'calendar_start_of_the_day': '07:00:00',
 	'calendar_now_indicator': '',
 	'calendar_display_not_qualified_areas': '',
+	'calendar_all_tools': '',
+	'calendar_all_areas': '',
+	'calendar_all_areastools': '',
 	'buddy_board_disclaimer': '',
 	'allow_bypass_interlock_on_failure': '',
 	'tool_interlock_failure_message': 'Communication with the interlock failed',
@@ -69,6 +72,7 @@ customizable_content = [
 	('out_of_time_reservation_email', '.html'),
 	('facility_rules_tutorial_email', '.html'),
 	('new_task_email', '.html'),
+	('reservation_ending_reminder_email', '.html'),
 	('reservation_reminder_email', '.html'),
 	('reservation_warning_email', '.html'),
 	('safety_issue_email', '.html'),
@@ -79,6 +83,7 @@ customizable_content = [
 	('reservation_cancelled_user_email', '.html'),
 	('reservation_created_user_email', '.html'),
 	('reorder_supplies_reminder_email', '.html'),
+	('counter_threshold_reached_email', '.html'),
 	('rates', '.json'),
 	('jumbotron_watermark', '.png'),
 ]
@@ -162,6 +167,9 @@ def customize(request, element):
 		set_customization('calendar_week_column_format', request.POST.get('calendar_week_column_format', ''))
 		set_customization('calendar_month_column_format', request.POST.get('calendar_month_column_format', ''))
 		set_customization('calendar_display_not_qualified_areas', request.POST.get('calendar_display_not_qualified_areas', ''))
+		set_customization('calendar_all_tools', request.POST.get('calendar_all_tools', ''))
+		set_customization('calendar_all_areas', request.POST.get('calendar_all_areas', ''))
+		set_customization('calendar_all_areastools', request.POST.get('calendar_all_areastools', ''))
 	else:
 		return HttpResponseBadRequest('Invalid customization')
 	return redirect('customization')
