@@ -134,23 +134,28 @@ def cancel(request, task_id):
 	task.resolution_time = timezone.now()
 	task.save()
 	determine_tool_status(task.tool)
+	send_task_updated_email(task, request.build_absolute_uri(task.tool.get_absolute_url()))
 	return redirect('tool_control')
 
 
-def send_task_updated_email(task, url, task_images: List[TaskImages]):
-	if not hasattr(settings, 'LAB_MANAGERS'):
-		return
-	attachments = None
-	if task_images:
-		attachments = [create_email_attachment(task_image.image, task_image.image.name) for task_image in task_images]
-	task.refresh_from_db()
-	if task.resolved:
-		task_user = task.resolver
-		task_status = 'resolved'
-	else:
-		task_user = task.last_updated_by
-		task_status = 'updated'
-	message = f"""
+def send_task_updated_email(task, url, task_images: List[TaskImages] = None):
+	try:
+		if not hasattr(settings, 'LAB_MANAGERS'):
+			return
+		attachments = None
+		if task_images:
+			attachments = [create_email_attachment(task_image.image, task_image.image.name) for task_image in task_images]
+		task.refresh_from_db()
+		if task.cancelled:
+			task_user = task.resolver
+			task_status = 'cancelled'
+		elif task.resolved:
+			task_user = task.resolver
+			task_status = 'resolved'
+		else:
+			task_user = task.last_updated_by
+			task_status = 'updated'
+		message = f"""
 A task for the {task.tool} was just modified by {task_user}.
 <br/><br/>
 The latest update is at the bottom of the description. The entirety of the task status follows: 
@@ -166,7 +171,11 @@ Task resolution description:<br/>
 <br/><br/>
 Visit {url} to view the tool control page for the task.<br/>
 """
-	send_mail(subject=f'{task.tool} task {task_status}', content=message, from_email=settings.SERVER_EMAIL, to=settings.LAB_MANAGERS, attachments=attachments, email_category=EmailCategory.TASKS)
+		send_mail(subject=f'{task.tool} task {task_status}', content=message, from_email=settings.SERVER_EMAIL, to=settings.LAB_MANAGERS, attachments=attachments, email_category=EmailCategory.TASKS)
+	except Exception as error:
+		site_title = get_customization('site_title')
+		error_message = f"{site_title} was unable to send the task updated email. The error message that was received is: " + str(error)
+		tasks_logger.exception(error_message)
 
 
 @staff_member_required(login_url=None)
@@ -189,13 +198,7 @@ def update(request, task_id):
 	set_task_status(request, task, request.POST.get('status'), request.user)
 	determine_tool_status(task.tool)
 	task_images = save_task_images(request, task)
-	try:
-		send_task_updated_email(task, request.build_absolute_uri(task.tool.get_absolute_url()), task_images)
-	except Exception as error:
-		site_title = get_customization('site_title')
-		error_message = f"{site_title} was unable to send the task updated email. The error message that was received is: " + str(error)
-		tasks_logger.exception(error_message)
-		pass
+	send_task_updated_email(task, request.build_absolute_uri(task.tool.get_absolute_url()), task_images)
 	if next_page == 'maintenance':
 		return redirect('maintenance')
 	else:
